@@ -9,7 +9,7 @@
 #                         and Technology (RIST). All rights reserved.
 # Copyright (c) 2015      IBM Corporation.  All rights reserved.
 #
-# Copyright (c) 2021-2023 Nanook Consulting.  All rights reserved.
+# Copyright (c) 2021-2024 Nanook Consulting  All rights reserved.
 # $COPYRIGHT$
 #
 # Additional copyrights may follow
@@ -710,6 +710,56 @@ sub patch_autotools_output {
     unlink("configure.patched");
 }
 
+sub export_version {
+    my ($name,$version) = @_;
+    $version =~ s/[^a-zA-Z0-9,.]//g;
+    my @version_splits = split(/\./,$version);
+    my $hex = sprintf("0x%04x%02x%02x", $version_splits[0], $version_splits[1], $version_splits[2]);
+    $m4 .= "m4_define([PMIX_${name}_MIN_VERSION], [$version])\n";
+    $m4 .= "m4_define([PMIX_${name}_NUMERIC_MIN_VERSION], [$hex])\n";
+}
+
+sub get_and_define_min_versions() {
+
+    open(IN, "VERSION") || my_die "Can't open VERSION";
+    while (<IN>) {
+          my $line = $_;
+          my @fields = split(/=/,$line);
+          if ($fields[0] eq "automake_min_version") {
+              if ($fields[1] ne "\n") {
+                  $pmix_automake_version = $fields[1];
+              }
+          }
+          elsif($fields[0] eq "autoconf_min_version") {
+              if ($fields[1] ne "\n") {
+                  $pmix_autoconf_version = $fields[1];
+              }
+          }
+          elsif($fields[0] eq "libtool_min_version") {
+              if ($fields[1] ne "\n") {
+                  $pmix_libtool_version = $fields[1];
+              }
+          }
+          elsif($fields[0] eq "hwloc_min_version") {
+              if ($fields[1] ne "\n") {
+                  export_version("HWLOC", $fields[1]);
+              }
+          }
+          elsif($fields[0] eq "event_min_version") {
+              if ($fields[1] ne "\n") {
+                  export_version("EVENT", $fields[1]);
+              }
+          }
+          elsif($fields[0] eq "flex_min_version") {
+              if ($fields[1] ne "\n") {
+                  export_version("FLEX", $fields[1]);
+              }
+          }
+    }
+    close(IN);
+}
+
+
 ##############################################################################
 
 sub in_tarball {
@@ -903,6 +953,8 @@ verbose "PMIx autogen (buckle up!)
 
 $step. Checking tool versions\n\n";
 
+get_and_define_min_versions();
+
 # Check the autotools revision levels
 &find_and_check("autoconf", $pmix_autoconf_search, $pmix_autoconf_version);
 &find_and_check("libtool", $pmix_libtoolize_search, $pmix_libtool_version);
@@ -916,33 +968,80 @@ verbose "\n$step. Checking for git submodules\n\n";
 # Make sure we got a submodule-full clone.  If not, abort and let a
 # human figure it out.
 if (-f ".gitmodules") {
-    open(IN, "git submodule status|")
-        || die "Can't run \"git submodule status\"";
-    while (<IN>) {
-        $_ =~ m/^(.)[0-9a-f]{40}\s+(\S+)/;
-        my $status = $1;
-        my $path   = $2;
+    print("   Doing some sanity checks for required submodule(s)...\n");
 
-        print("=== Submodule: $path\n");
-        # Make sure the submodule is there
-        if ($status eq "-") {
-            print("    ==> ERROR: Missing
+    # Do a quick sanity check to ensure that required
+    # submodule(s) are at least present (e.g., they won't be present
+    # if you downloaded a GitHub.com-created tarball).
+    open(IN, ".gitmodules") ||
+        die "Can't open .gitmodules";
+    while (<IN>) {
+        # Find "path = " lines
+        if (!($_ =~ m/^\s+path = (.+)$/)) {
+            next;
+        }
+        my $path = $1;
+
+        # Check that the path exists and is non-empty.
+        my $happy = 1;
+        my $havefiles = 1;
+        if (! -d $path) {
+            $happy = 0;
+        } else {
+            opendir(DIR, $path) ||
+                my_die "Can't open $path directory";
+            my @files = readdir(DIR);
+            closedir(DIR);
+
+            $havefiles = 0
+                if ($#files < 4);
+        }
+
+        if (!$happy) {
+            print("    ==> ERROR: Missing submodule directory
+
+The submodule path \"$path\" is missing.\n\n");
+            exit(1);
+        }
+
+        if (!$havefiles) {
+            print("    ==> ERROR: Missing submodule files
+
+The submodule \"$path\" files are missing.\n\n");
+            exit(1);
+        }
+
+    }
+    if (-d ".git") {
+        open(IN, "git submodule status|")
+            || die "Can't run \"git submodule status\"";
+        while (<IN>) {
+            $_ =~ m/^(.)[0-9a-f]{40}\s+(\S+)/;
+            my $status = $1;
+            my $path   = $2;
+
+            print("=== Submodule: $path\n");
+
+            # Make sure the submodule is there
+            if ($status eq "-") {
+                print("    ==> ERROR: Missing
 
 The submodule \"$path\" is missing.
 
 Perhaps you forgot to \"git clone --recursive ...\", or you need to
- \"git submodule update --init --recursive\"...?\n\n");
-            exit(1);
-        }
+\"git submodule update --init --recursive\"...?\n\n");
+                exit(1);
+            }
 
-        # See if the commit in the submodule is not the same as the
-        # commit that the git submodule thinks it should be.
-        elsif ($status eq "+") {
-            print("    ==> WARNING: Submodule hash is different than upstream.
+            # See if the commit in the submodule is not the same as the
+            # commit that the git submodule thinks it should be.
+            elsif ($status eq "+") {
+                print("    ==> WARNING: Submodule hash is different than upstream.
          If this is not intentional, you may want to run:
          \"git submodule update --init --recursive\"\n");
-        } else {
-            print("    Local hash is what is expected by the submodule (good!)\n");
+            } else {
+                print("    Local hash is what is expected by the submodule (good!)\n");
+            }
         }
     }
 }
