@@ -17,7 +17,7 @@
  * Copyright (c) 2016      University of Houston. All rights reserved.
  * Copyright (c) 2018      Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
- * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2024 Nanook Consulting  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -63,6 +63,9 @@
 #ifdef HAVE_PATHS_H
 #    include <paths.h>
 #endif
+#ifdef HAVE_FCNTL_H
+#    include <fcntl.h>
+#endif
 
 #ifdef _PATH_MOUNTED
 #    define MOUNTED_FILE _PATH_MOUNTED
@@ -73,6 +76,7 @@
 #include "src/include/pmix_globals.h"
 #include "src/include/pmix_stdint.h"
 #include "src/util/pmix_argv.h"
+#include "src/util/pmix_basename.h"
 #include "src/util/pmix_os_path.h"
 #include "src/util/pmix_output.h"
 #include "src/util/pmix_path.h"
@@ -206,8 +210,9 @@ char *pmix_path_findv(char *fname, int mode, char **envv, char *wrkdir)
         pmix_argv_append(&dirc, &dirv, wrkdir);
     }
 
-    if (NULL == dirv)
+    if (NULL == dirv) {
         return NULL;
+    }
     fullpath = pmix_path_find(fname, dirv, mode, envv);
     PMIx_Argv_free(dirv);
     return fullpath;
@@ -229,7 +234,6 @@ char *pmix_path_findv(char *fname, int mode, char **envv, char *wrkdir)
 char *pmix_path_access(char *fname, char *path, int mode)
 {
     char *fullpath = NULL;
-    struct stat buf;
 
     /* Allocate space for the full pathname. */
     if (NULL == path) {
@@ -240,45 +244,7 @@ char *pmix_path_access(char *fname, char *path, int mode)
     if (NULL == fullpath)
         return NULL;
 
-    /* first check to see - is this a file or a directory? We
-     * only want files
-     */
-    /* coverity[TOCTOU] */
-    if (0 != stat(fullpath, &buf)) {
-        /* couldn't stat the path - obviously, this also meets the
-         * existence check, if that was requested
-         */
-        free(fullpath);
-        return NULL;
-    }
-
-    if (!(S_IFREG & buf.st_mode) && !(S_IFLNK & buf.st_mode)) {
-        /* this isn't a regular file or a symbolic link, so
-         * ignore it
-         */
-        free(fullpath);
-        return NULL;
-    }
-
-    /* check the permissions */
-    if ((X_OK & mode) && !(S_IXUSR & buf.st_mode)) {
-        /* if they asked us to check executable permission,
-         * and that isn't set, then return NULL
-         */
-        free(fullpath);
-        return NULL;
-    }
-    if ((R_OK & mode) && !(S_IRUSR & buf.st_mode)) {
-        /* if they asked us to check read permission,
-         * and that isn't set, then return NULL
-         */
-        free(fullpath);
-        return NULL;
-    }
-    if ((W_OK & mode) && !(S_IWUSR & buf.st_mode)) {
-        /* if they asked us to check write permission,
-         * and that isn't set, then return NULL
-         */
+    if (0 != access(fullpath, mode)) {
         free(fullpath);
         return NULL;
     }
@@ -409,262 +375,106 @@ char *pmix_find_absolute_path(char *app_name)
 }
 
 /**
- * Read real FS type from /etc/mtab, needed to translate autofs fs type into real fs type
- * TODO: solaris? OSX?
- * Limitations: autofs on solaris/osx will be assumed as "nfs" type
- */
-
-static char *pmix_check_mtab(char *dev_path)
-{
-    PMIX_HIDE_UNUSED_PARAMS(dev_path);
-
-#ifdef HAVE_MNTENT_H
-    FILE *mtab = NULL;
-    struct mntent *part = NULL;
-
-    if ((mtab = setmntent(MOUNTED_FILE, "r")) != NULL) {
-        while (NULL != (part = getmntent(mtab))) {
-            if ((NULL != part->mnt_dir) && (NULL != part->mnt_type)
-                && (0 == strcmp(part->mnt_dir, dev_path))) {
-                endmntent(mtab);
-                return strdup(part->mnt_type);
-            }
-        }
-        endmntent(mtab);
-    }
-#endif
-    return NULL;
-}
-
-/**
- * @brief Figure out, whether fname is on network file system
+ * @brief Figure out whether fname is on network file system
  *
- * Try to figure out, whether the file name specified through fname is
+ * Try to figure out whether the file name specified through fname is
  * on any network file system (currently NFS, Lustre, Panasas and GPFS).
  *
- * If the file is not created, the parent directory is checked.
- * This allows checking for NFS prior to opening the file.
- *
  * @fname[in]          File name to check
  * @fstype[out]        File system type if retval is true
  *
- * @retval true                If fname is on NFS, Lustre, Panasas or GPFS
- * @retval false               otherwise
+ * @retval true       If fname is on NFS, Lustre, Panasas or GPFS
+ * @retval false      otherwise
  *
- *
- * Linux:
- *   statfs(const char *path, struct statfs *buf);
- *          with fsid_t  f_fsid;  (in kernel struct{ int val[2] };)
- *          return 0 success, -1 on failure with errno set.
- *   statvfs (const char *path, struct statvfs *buf);
- *          with unsigned long  f_fsid;   -- returns wrong info
- *          return 0 success, -1 on failure with errno set.
- * Solaris:
- *   statvfs (const char *path, struct statvfs *buf);
- *          with f_basetype, contains a string of length FSTYPSZ
- *          return 0 success, -1 on failure with errno set.
- * FreeBSD:
- *   statfs(const char *path, struct statfs *buf);
- *          with f_fstypename, contains a string of length MFSNAMELEN
- *          return 0 success, -1 on failure with errno set.
- *          compliant with: 4.4BSD.
- * NetBSD:
- *   statvfs (const char *path, struct statvfs *buf);
- *          with f_fstypename, contains a string of length VFS_NAMELEN
- *          return 0 success, -1 on failure with errno set.
- * Mac OSX (10.6.2 through 10.9):
- *   statvfs(const char * restrict path, struct statvfs * restrict buf);
- *          with fsid    Not meaningful in this implementation.
- *          is just a wrapper around statfs()
- *   statfs(const char *path, struct statfs *buf);
- *          with f_fstypename, contains a string of length MFSTYPENAMELEN
- *          return 0 success, -1 on failure with errno set.
  */
-#ifndef LL_SUPER_MAGIC
-#    define LL_SUPER_MAGIC 0x0BD00BD0 /* Lustre magic number */
-#endif
-#ifndef NFS_SUPER_MAGIC
-#    define NFS_SUPER_MAGIC 0x6969
-#endif
-#ifndef PAN_KERNEL_FS_CLIENT_SUPER_MAGIC
-#    define PAN_KERNEL_FS_CLIENT_SUPER_MAGIC 0xAAD7AAEA /* Panasas FS */
-#endif
-#ifndef GPFS_SUPER_MAGIC
-#    define GPFS_SUPER_MAGIC 0x47504653 /* That's GPFS in ASCII */
-#endif
-#ifndef AUTOFS_SUPER_MAGIC
-#    define AUTOFS_SUPER_MAGIC 0x0187
-#endif
-#ifndef PVFS2_SUPER_MAGIC
-#    define PVFS2_SUPER_MAGIC 0x20030528
-#endif
-
-#define MASK2 0xffff
-#define MASK4 0xffffffff
-
-bool pmix_path_nfs(char *fname, char **ret_fstype)
+bool pmix_path_nfs(char *fname, char **fstype)
 {
-    int i;
-    int fsrc = -1;
-    int vfsrc = -1;
-    int trials;
-    char *file = strdup(fname);
-#if defined(USE_STATFS)
-    struct statfs fsbuf;
-#endif
-#if defined(HAVE_STATVFS)
-    struct statvfs vfsbuf;
-#endif
-    /*
-     * Be sure to update the test (test/util/pmix_path_nfs.c)
-     * while adding a new Network/Cluster Filesystem here
-     */
-    static struct fs_types_t {
-        unsigned long long f_fsid;
-        unsigned long long f_mask;
-        const char *f_fsname;
-    } fs_types[] = {{LL_SUPER_MAGIC, MASK4, "lustre"},
-                    {NFS_SUPER_MAGIC, MASK2, "nfs"},
-                    {AUTOFS_SUPER_MAGIC, MASK2, "autofs"},
-                    {PAN_KERNEL_FS_CLIENT_SUPER_MAGIC, MASK4, "panfs"},
-                    {GPFS_SUPER_MAGIC, MASK4, "gpfs"},
-                    {PVFS2_SUPER_MAGIC, MASK4, "pvfs2"}};
-#define FS_TYPES_NUM (int) (sizeof(fs_types) / sizeof(fs_types[0]))
+#ifdef HAVE_MNTENT_H
+    struct stat s;
+    struct mntent mnt;
+    FILE *fp;
+    dev_t dev;
+    char buf[1024];
+    int fd, n;
+    char* fs_types[] = {
+        "lustre",
+        "nfs",
+        "autofs",
+        "panfs",
+        "gpfs",
+        "pvfs2",
+        NULL
+    };
+    char *parent;
 
-    /*
-     * First, get the OS-dependent struct stat(v)fs buf.  This may
-     * return the ESTALE error on NFS, if the underlying file/pmix_path.has
-     * changed.
-     */
-again:
-#if defined(USE_STATFS)
-    trials = 5;
-    do {
-        fsrc = statfs(file, &fsbuf);
-    } while (-1 == fsrc && ESTALE == errno && (0 < --trials));
-#endif
-#if defined(HAVE_STATVFS)
-    trials = 5;
-    do {
-        vfsrc = statvfs(file, &vfsbuf);
-    } while (-1 == vfsrc && ESTALE == errno && (0 < --trials));
-#endif
-
-    /* In case some error with the current filename, try the parent
-       directory */
-    if (-1 == fsrc && -1 == vfsrc) {
-        char *last_sep;
-
-        pmix_output_verbose(10, 0,
-                             "pmix_path_nfs: stat(v)fs on file:%s failed errno:%d directory:%s\n",
-                             fname, errno, file);
-        if (EPERM == errno) {
-            free(file);
-            if (NULL != ret_fstype) {
-                *ret_fstype = NULL;
-            }
+    fd = open(fname, O_RDONLY);
+    if (0 > fd) {
+        // try the parent
+        parent = pmix_dirname(fname);
+        fd = open(parent, O_RDONLY);
+        free(parent);
+        if (0 > fd) {
+            // give up
             return false;
         }
+    }
+    if (fstat(fd, &s) != 0) {
+        return false;
+    }
+    close(fd);
 
-        last_sep = strrchr(file, PMIX_PATH_SEP[0]);
-        /* Stop the search, when we have searched past root '/' */
-        if (NULL == last_sep || (1 == strlen(last_sep) && PMIX_PATH_SEP[0] == *last_sep)) {
-            free(file);
-            if (NULL != ret_fstype) {
-                *ret_fstype = NULL;
-            }
+    // retain the inode of the file
+    dev = s.st_dev;
+
+    // try a couple of possible locations for the
+    // mount table
+    if ((fp = setmntent("/proc/mounts", "r")) == NULL) {
+        if ((fp = setmntent("/etc/mtab", "r")) == NULL) {
             return false;
         }
-        *last_sep = '\0';
-
-        goto again;
     }
 
-    /* Next, extract the magic value */
-    for (i = 0; i < FS_TYPES_NUM; i++) {
-#if defined(USE_STATFS)
-        /* These are uses of struct statfs */
-#    if defined(HAVE_STRUCT_STATFS_F_FSTYPENAME)
-        if (0 == fsrc
-            && 0
-                   == strncasecmp(fs_types[i].f_fsname, fsbuf.f_fstypename,
-                                  sizeof(fsbuf.f_fstypename))) {
-            goto found;
+    // search the mount table for an entry with
+    // matching inode
+    while (getmntent_r(fp, &mnt, buf, sizeof(buf))) {
+        fd = open(mnt.mnt_dir, O_RDONLY);
+        if (0 > fd) {
+            // probably lack permissions
+            continue;
         }
-#    endif
-#    if defined(HAVE_STRUCT_STATFS_F_TYPE)
-        if (0 == fsrc && fs_types[i].f_fsid == (fsbuf.f_type & fs_types[i].f_mask)) {
-            goto found;
+        if (fstat(fd, &s) != 0) {
+            close(fd);
+            continue;
         }
-#    endif
-#endif
 
-#if defined(HAVE_STATVFS)
-        /* These are uses of struct statvfs */
-#    if defined(HAVE_STRUCT_STATVFS_F_BASETYPE)
-        if (0 == vfsrc
-            && 0
-                   == strncasecmp(fs_types[i].f_fsname, vfsbuf.f_basetype,
-                                  sizeof(vfsbuf.f_basetype))) {
-            goto found;
-        }
-#    endif
-#    if defined(HAVE_STRUCT_STATVFS_F_FSTYPENAME)
-        if (0 == vfsrc
-            && 0
-                   == strncasecmp(fs_types[i].f_fsname, vfsbuf.f_fstypename,
-                                  sizeof(vfsbuf.f_fstypename))) {
-            goto found;
-        }
-#    endif
-#endif
-    }
-
-    free(file);
-    if (NULL != ret_fstype) {
-        *ret_fstype = NULL;
-    }
-    return false;
-
-#if defined(HAVE_STRUCT_STATFS_F_FSTYPENAME) || defined(HAVE_STRUCT_STATFS_F_TYPE) \
-    || defined(HAVE_STRUCT_STATVFS_F_BASETYPE) || defined(HAVE_STRUCT_STATVFS_F_FSTYPENAME)
-found:
-#endif
-
-    free(file);
-    if (AUTOFS_SUPER_MAGIC == fs_types[i].f_fsid) {
-        char *fs_type = pmix_check_mtab(fname);
-        int x;
-        if (NULL != fs_type) {
-            for (x = 0; x < FS_TYPES_NUM; x++) {
-                if (AUTOFS_SUPER_MAGIC == fs_types[x].f_fsid) {
-                    continue;
-                }
-                if (0 == strcasecmp(fs_types[x].f_fsname, fs_type)) {
-                    pmix_output_verbose
-                        (10, 0, "pmix_path_nfs: file:%s on fs:%s\n", fname, fs_type);
-                    free(fs_type);
-                    if (NULL != ret_fstype) {
-                        *ret_fstype = strdup(fs_types[x].f_fsname);
-                    }
+        if (s.st_dev == dev) {
+            *fstype = strdup(mnt.mnt_type);
+            close(fd);
+            endmntent(fp);
+            // check if this is a file system of concern
+            for (n=0; NULL != fs_types[n]; n++) {
+                if (0 == strcmp(fs_types[n], mnt.mnt_type)) {
+                    // yep, this is a shared file system
                     return true;
                 }
             }
-            free(fs_type);
-            if (NULL != ret_fstype) {
-                *ret_fstype = NULL;
-            }
+            // if we get here, then this is not a file
+            // system of concern
             return false;
         }
+        close(fd);
     }
 
-    pmix_output_verbose(10, 0, "pmix_path_nfs: file:%s on fs:%s\n", fname, fs_types[i].f_fsname);
-    if (NULL != ret_fstype) {
-        *ret_fstype = strdup(fs_types[i].f_fsname);
-    }
-    return true;
+    endmntent(fp);
 
-#undef FS_TYPES_NUM
+    // Should never reach here.
+    return false;
+#else
+    // cannot do anything
+    PMIX_HIDE_UNUSED_PARAMS(fname, fstype);
+    *fstype = strdup("unknown");
+    return false;
+#endif
 }
 
 int pmix_path_df(const char *path, uint64_t *out_avail)
